Topsis stands for The Technique for Order of Preference by Similarity to Ideal Solution. It is used for multi-criteria decision making.Topsis is based on the concept that the chosen alternative should have the shortest geometric distance from the positive ideal solution and the longest geometric distance from the negative ideal solution.
The user needs to give the name of the dataset on which Topsis is to be performed and the weights and impacts.The impacts should contain only '+' and '-' signs.
python Arsh_Topsis.py Dataset weights impacts